==> lxqt-panel_1.4.0.orig.tar.xz: lxqt-panel-1.4.0/plugin-quicklaunch/translations/quicklaunch_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="227"/>
        <source>Drop Error</source>
        <translation>Errorea jaregitean</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="228"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>&apos;%1&apos; fitxategia/URLa ezin da QuickLaunch-en txertatu oraingoz</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="334"/>
        <source>Drop application
icons here</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Mugitu ezkerrera</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Mugitu eskuinera</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>Kendu abio azkarretik</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="72"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.0.0.tar.xz: lxqt-panel-2.0.0/plugin-quicklaunch/translations/quicklaunch_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="227"/>
        <source>Drop Error</source>
        <translation>Jaregin errorea</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="228"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>&apos;%1&apos; fitxategia/URLa ezin da QuickLaunch-en txertatu oraingoz</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="334"/>
        <source>Drop application
icons here</source>
        <translation>Jarri aplikazioa
ikonoak hemen</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>(Ctrl + DND)</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Mugitu ezkerrera</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Mugitu eskuinera</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="63"/>
        <source>Remove from quicklaunch</source>
        <translation>Kendu abiarazte azkarretik</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="72"/>
        <source>Refresh</source>
        <translation>Freskatu</translation>
    </message>
</context>
</TS>
